@@ -304,7 +304,7 @@ new_8_4_check_for_enum_types(migratorContext *ctx, Cluster whichCluster)
 
 /*
  * new_8_5_populate_pg_largeobject_metadata()
- *	new >= 8.5
+ *	new >= 8.5, old <= 8.4
  *	8.5 has a new pg_largeobject permission table
  */
 void
